/**
 * @file
 * @brief Logarithm for continuum calculations
 * @author  Andreas Maier <a.maier@tum.de>
 * @version 1.0.0
 *
 * @section LICENSE
 *
 * Copyright 2014 Andreas Maier
 *
 * This file is part of the QQbar_threshold library.
 *
 * The QQbar_threshold library is free software; you can redistribute it and/or
 * modify it under the terms of the GNU General Public License as
 * published by the Free Software Foundation; either version 3 of
 * the License, or (at your option) any later version.
 *
 * The QQbar_threshold library is distributed in the hope that it will be useful, but
 * WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the GNU
 * General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with the QQbar_threshold library. If not, see
 * <http://www.gnu.org/licenses/>.
 *
 */
#pragma once
#include "parameters.hpp"

namespace QQbar_threshold{
  namespace detail{
    typedef std::complex<double> complex;

    //! Logarithm for continuum calculations
    /**
     * @param lam  The value of \f$\lambda = \frac{\alpha_s C_F}{2} \sqrt{-\frac{m}{E + i\Gamma}}$\f.
     * @param p    Further parameters.
     */
    complex log_lam(complex const & lam, parameters const & p);
    //! Logarithm for continuum calculations
    /**
     * @param lam  The value of \f$\lambda = \frac{\alpha_s C_F}{2} \sqrt{-\frac{m}{E + i\Gamma}}$\f.
     * @param mu   Renormalisation scale.
     * @param p    Further parameters.
     */
    complex log_lam(complex const & lam, double mu, parameters const & p);
  }
}
