/**
 * @file
 * @brief Top quark decay width
 *
 * @author  Andreas Maier <a.maier@tum.de>
 * @version 1.0.0
 *
 * @section LICENSE
 *
 * Copyright 2015, 2016 Andreas Maier
 *
 * This file is part of the QQbar_threshold library.
 *
 * The QQbar_threshold library is free software; you can redistribute it and/or
 * modify it under the terms of the GNU General Public License as
 * published by the Free Software Foundation; either version 3 of
 * the License, or (at your option) any later version.
 *
 * The QQbar_threshold library is distributed in the hope that it will be useful, but
 * WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the GNU
 * General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with the QQbar_threshold library. If not, see
 * <http://www.gnu.org/licenses/>.
 *
 */
#pragma once

#include "parameters.hpp"

//! -
namespace QQbar_threshold{

  //! Computes the top quark decay width
  /**
   *
   * @param mu    renormalisation scale
   * @param m     top quark mass
   * @param o     perturbative order (LO, NLO, N2LO, or N3LO)
   * @param opt   further options
   * @return      The decay width
   *
   * The supported options and their default values are:
   *   - options::mass_scheme = {\ref PSshift, mu_f_top}
   *   - options::alpha_s_mZ = #alpha_s_mZ
   *   - options::contributions = (all set to 1)
   *   - options::r4 = 824.12 (for nl == 5)
   *
   * @see options
   *
   * \internal
   *  @TODO:
   * - options::beyond_QCD = SM::all
   * - options::alpha = #alpha_mZ
   * - options::m_Higgs = #m_Higgs
   * - options::Yukawa_factor = 1
   * - options::ml = 0
   *

   */
  double top_width(
      double mu, double m, order o,
      options opt = top_options()
  );

}
