#ifdef NDEBUG
#undef NDEBUG
#endif
#include <iostream>
#include <cmath>

#include "xsection.hpp"
#include "load_grid.hpp"
#include "threshold.hpp"
#include "mass_schemes.hpp"

int main(){
  using namespace QQbar_threshold::pert_order;
  using QQbar_threshold::SM;
  using QQbar_threshold::threshold;
  using QQbar_threshold::Pole;
  using QQbar_threshold::top_options;
  using QQbar_threshold::load_nonresonant_grid;

  auto opt = top_options();
  opt.alpha = 1/137.03599907430635;
  opt.mass_scheme = {Pole, 0};
  opt.resonant_only = false;
  auto opt_no_NR = opt;
  opt_no_NR.resonant_only = true;
  constexpr double mt = 172.;
  constexpr double mu = 90.;
  constexpr double width = 1.4;
  constexpr order o = NLO;
  constexpr double ep = 1e-5;
  size_t i;

  constexpr std::array<double, 4> results_no_cut{{
      -0.04066908791539853,
        -0.03867108895334381,
        -0.03672492873594868,
        -0.034828836457821866
        }};
  constexpr std::array<double, 4> results_cut15{{
      -0.053447082717894334,
        -0.0523544544974226,
        -0.05129029472841318,
        -0.05025362279975143
        }};
  double constexpr mt_low = 150.;
  constexpr std::array<double, 4> results_mt_low{{
      -0.06185457267366709,
        -0.060411709963043014,
        -0.059012102916986775,
        -0.05765403691885218
        }};


  for(int j = 0; j < 2; ++j){
    std::cout << "--------------------------------------------------\n";
    std::cout << "no cut:\n";
    std::cout << "--------------------------------------------------\n";
    opt.invariant_mass_cut = top_options().invariant_mass_cut;
    i = 0;
    for(double e = -5; e < 5; e += 3){
      double diff = std::abs(
          ttbar_R_ratio(threshold() + e, mu, {mt, width}, o, opt)
          - ttbar_R_ratio(threshold() + e, mu, {mt, width}, o, opt_no_NR)
          - results_no_cut[i++]
      );
      std::cout << "e = " << e << ": " << diff;
      assert(diff < ep);
      std::cout << " (ok)\n";
    }

    std::cout << "--------------------------------------------------\n";
    std::cout << "invariant_mass_cut = 15 GeV:\n";
    std::cout << "--------------------------------------------------\n";
    opt.invariant_mass_cut = 15;
    i = 0;
    for(double e = -5; e < 5; e += 3){
      double diff = std::abs(
          ttbar_R_ratio(threshold() + e, mu, {mt, width}, o, opt)
          - ttbar_R_ratio(threshold() + e, mu, {mt, width}, o, opt_no_NR)
          - results_cut15[i++]
      );
      std::cout << "e = " << e << ": " << diff;
      assert(diff < ep);
      std::cout << " (ok)\n";
    }

    std::cout << "--------------------------------------------------\n";
    std::cout << "m = 150 GeV:\n";
    std::cout << "--------------------------------------------------\n";
    i = 0;
    for(double e = -5; e < 5; e += 3){
      double diff = std::abs(
          ttbar_R_ratio(threshold() + e, mu, {mt_low, width}, o, opt)
          - ttbar_R_ratio(threshold() + e, mu, {mt_low, width}, o, opt_no_NR)
          - results_mt_low[i++]
      );
      std::cout << "e = " << e << ": " << diff;
      assert(diff < ep);
      std::cout << " (ok)\n";
    }
    load_nonresonant_grid("../grids/non-resonant_grid.tsv");
  }

}
